==> tmaid-2.1.11.tar.gz: tmaid-2.1.11/src/other.h <==
/*
    Text maid
    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifndef __OTHER_H__
#define __OTHER_H__


#include <gtk/gtk.h>


#define iskanji(ch) (((ch)&0x80)!=0)


/*	åܥåɽ
	title,ȥ
	 text,ʸ
	  def,ǥեȤΥܥ
	  ...,ܥΥ٥
	  RET,줿ܥ													*/
gint message_box(gchar *title,gchar *text,gint def,...);


/*	ե¸߳ǧ
	file,ե̾
	 RET,TRUE:¸ߤ,FALSE:¸ߤʤ										*/
gboolean isfile(gchar *file);


/*	եΥեѥ
	file,ե̾
	 RET,եѥ															*/
gchar *get_full_path(gchar *file);


/*	Сꤹ
	   scroll,륦å
	     func,ʥؿ
	func_data,ǡ
	      min,Ǿ
	      max,
	     page,ڡ
	      pos,															*/
void set_scroll_bar(GtkWidget *scroll,GtkSignalFunc func,gpointer func_data,
										gint min,gint max,gint page,gint pos);


/*	WindowƤ򥹥뤹
	widget,å
	    dx,Xΰư
	    dy,Yΰư
	     x,뤹ϰϤαXɸ
	     y,뤹ϰϤαYɸ
	 width,뤹ϰϤ
	height,뤹ϰϤι⤵											*/
void scroll_window(GtkWidget *widget,gint dx,gint dy,
										gint x,gint y,gint width,gint height);


/*	͢ʸ
	 value,
	 radix,
	  wide,
	signed,TRUE:椢,FALSE:ʤ
	   RET,ʸ															*/
gchar *valstr(gint value,gint radix,gint wide,gboolean signed);


/*	ʸ󢪿
	 value,
	   str,ʸ
	 radix,
	signed,TRUE:椢,FALSE:ʤ
	   RET,TRUE:ｪλ,FALSE:顼										*/
gboolean strval(gint *value,gchar *str,gint radix,gboolean signed);


#endif

==> tmaid-2.1.16.tar.gz: tmaid-2.1.16/src/other.h <==
/*
    Text maid
    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifndef __OTHER_H__
#define __OTHER_H__


#include <gtk/gtk.h>


//#define iskanji(ch) (((ch)&0x80)!=0)


/*	åܥåɽ
	title,ȥ
	 text,ʸ
	  def,ǥեȤΥܥ
	  ...,ܥΥ٥
	  RET,줿ܥ													*/
gint message_box(gchar *title,gchar *text,gint def,...);


/*	ե¸߳ǧ
	file,ե̾
	 RET,TRUE:¸ߤ,FALSE:¸ߤʤ										*/
gboolean isfile(gchar *file);


/*	եΥեѥ
	file,ե̾
	 RET,եѥ															*/
gchar *get_full_path(gchar *file);


/*	Сꤹ
	   scroll,륦å
	     func,ʥؿ
	func_data,ǡ
	      min,Ǿ
	      max,
	     page,ڡ
	      pos,															*/
void set_scroll_bar(GtkWidget *scroll,GtkSignalFunc func,gpointer func_data,
										gint min,gint max,gint page,gint pos);


/*	WindowƤ򥹥뤹
	widget,å
	    dx,Xΰư
	    dy,Yΰư
	    px,뤹ϰϤαXɸ
	    py,뤹ϰϤαYɸ
	 width,뤹ϰϤ
	height,뤹ϰϤι⤵											*/
void scroll_window(GtkWidget *widget,gint dx,gint dy,
									gint px,gint py,gint width,gint height);


/*	͢ʸ
	 value,
	 radix,
	  wide,
	signed,TRUE:椢,FALSE:ʤ
	   RET,ʸ															*/
gchar *valstr(gint value,gint radix,gint wide,gboolean signed);


/*	ʸ󢪿
	 value,
	   str,ʸ
	 radix,
	signed,TRUE:椢,FALSE:ʤ
	   RET,TRUE:ｪλ,FALSE:顼										*/
gboolean strval(gint *value,gchar *str,gint radix,gboolean signed);


#endif
